@@ -71,6 +71,8 @@ class Chord(object):
         instances=0,
         verb="occur together in",
         symmetric=True,
+        title="",
+        arc_numbers=False,
     ):
         self.html = Chord.template
         self.matrix = matrix
@@ -99,6 +101,8 @@ class Chord(object):
         self.instances = instances
         self.verb = verb
         self.symmetric = symmetric
+        self.title = title
+        self.arc_numbers = arc_numbers
 
     def __str__(self):
         return self.html
@@ -136,6 +140,8 @@ class Chord(object):
                 "instances": self.instances,
                 "verb": self.verb,
                 "symmetric": "true" if self.symmetric else "false",
+                "title": self.title,
+                "arc_numbers": self.arc_numbers,
             }
 
             result = requests.post(url, json=payload, auth=(Chord.user, Chord.key))
